enum Components {
Single(u32),
Swizzle {
size: VectorSize,
pattern: [SwizzleComponent; 4],
},
}Expand description
A single vector component or swizzle.
This represents the things that can appear after the . in a vector access
expression: either a single component name, or a series of them,
representing a swizzle.
Variants
Implementations
Sourceimpl Components
impl Components
const fn letter_component(letter: char) -> Option<SwizzleComponent>
fn single_component(name: &str, name_span: Span) -> Result<u32, Box<Error<'_>>>